/*
	RSAREF.H - header file for RSAEURO cryptographic toolkit

    Copyright (c) J.S.A.Kapp 1994 - 1996.

	RSAEURO - RSA Library compatible with RSAREF 2.0.

	All functions prototypes are the Same as for RSAREF.
	To aid compatiblity the source and the files follow the
	same naming comventions that RSAREF uses.  This should aid
        direct importing to your applications.

	This library is legal everywhere outside the US.  And should
	NOT be imported to the US and used there.

	This header file is used to launch the RSAEURO.H header file.
	Provided for compatiblity with RSAREF.

	Revision 1.00 - JSAK.
*/

#ifndef _RSAREF_H_
#define _RSAREF_H_

#include "rsaeuro.h"

#endif /* _RSAREF_H_ */
